@@ -285,6 +285,28 @@ test_that("wkt_translate_wkb() works with nested collections", {
   expect_identical(wkt_translate_wkb(wkt), list(collection))
 })
 
+test_that("wkt_translate_* has reasonable error messages", {
+  # close enough to inf to trigger the parse check
+  expect_error(wkt_translate_wkt("MULTIPOINT (iambic 3)"), class = "WKParseException")
+  expect_error(wkt_translate_wkt(""), class = "WKParseException")
+  expect_error(wkt_translate_wkt("SRID=fish;POINT (30 10)"), class = "WKParseException")
+  expect_error(wkt_translate_wkt("SRID="), class = "WKParseException")
+  expect_error(wkt_translate_wkt("POINT (fish fish)"), class = "WKParseException")
+  expect_error(wkt_translate_wkt("POINT ("), class = "WKParseException")
+  expect_error(wkt_translate_wkt("POINT (3"), class = "WKParseException")
+  expect_error(wkt_translate_wkt("POINT"), class = "WKParseException")
+  expect_error(wkt_translate_wkt("POINT "), class = "WKParseException")
+  expect_error(wkt_translate_wkt("POINT (30 10="), class = "WKParseException")
+  # keeping commented out until the end-of-input assertion is added
+  # expect_error(wkt_translate_wkt("POINT (30 10)P"), class = "WKParseException")
+  expect_error(wkt_translate_wkt("LINESTRING (30 10, 0 0="), class = "WKParseException")
+
+})
+
+test_that("wkt_translate_* can handle non-finite values", {
+  expect_identical(wkt_translate_wkt("MULTIPOINT (nan nan)"), "MULTIPOINT ((nan nan))")
+})
+
 test_that("wkt_translate_* doesn't segfault on other inputs", {
   expect_error(wkt_translate_wkt(as_wkb("POINT (30 10)")), class = "Rcpp::not_compatible")
   expect_error(wkt_translate_wkt(as_wksxp("POINT (30 10)")), class = "Rcpp::not_compatible")
